@@ -1,15 +1,17 @@
 from datetime import datetime
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List
 
-from python_on_whales.utils import DockerCamelModel
+from python_on_whales.utils import DockerCamelModel, all_fields_optional
 
 
+@all_fields_optional
 class NetworkIPAM(DockerCamelModel):
     driver: str
     config: List[Dict[str, Any]]
-    options: Optional[Dict[str, Any]]
+    options: Dict[str, Any]
 
 
+@all_fields_optional
 class NetworkContainer(DockerCamelModel):
     name: str
     endpoint_id: str
@@ -18,6 +20,7 @@ class NetworkContainer(DockerCamelModel):
     ipv6_address: str
 
 
+@all_fields_optional
 class NetworkInspectResult(DockerCamelModel):
     name: str
     id: str
@@ -32,5 +35,5 @@ class NetworkInspectResult(DockerCamelModel):
     containers: Dict[str, NetworkContainer]
     options: Dict[str, Any]
     labels: Dict[str, str]
-    config_from: Optional[dict]
-    config_only: Optional[bool]
+    config_from: dict
+    config_only: bool
